drop_write_stdout

Function drop_write_stdout 

pub fn drop_write_stdout(bytes: &[u8])
Writes pre-encoded bytes to stdout, dropping write errors instead of surfacing them. The byte-slice sibling of drop_print! for output that is not produced via format args (ex. serialized JSON, bundle contents).